@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: colormnu.cc,v 1.5 2000/12/20 14:46:43 lav Exp $ */
+/* $Id: colormnu.cc,v 1.6 2008/09/02 05:04:43 lav Exp $ */
 
 #include <config.h>
 
@@ -25,7 +25,7 @@
 #include "edit.h"
 #include "colormnu.h"
 #include "options.h"
-#include "xalloca.h"
+#include <alloca.h>
 
 void ColorsSaveToFile(const char *f)
 {
