@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: edit.cc,v 1.44 2008/09/02 05:04:43 lav Exp $ */
+/* $Id: edit.cc,v 1.46 2009/12/12 16:58:14 lav Exp $ */
 
 /* edit.c : main editor loop */
 
@@ -550,7 +550,7 @@ void  PrintUsage(int arg)
 	  "    --dump-colors  dump default color map to stdout and exit\n"
 	  "    --mmap         load file using mmap (read only)\n"
 	  "    --mmap-rw      mmap read-write. Use with extreme caution,\n"
-	  "                   expecially on your hard disk!\n"
+	  "                   especially on your hard disk!\n"
 	  "                   All changes go directly to file/disk.\n"
 	  "    --help         this description\n"
 	  "    --version      print LE version\n"
@@ -565,7 +565,7 @@ static bool has_widechars()
 {
    for(int c=' '; c<256; c++)
    {
-      wchar_t w=btowc(c);
+      wint_t w=btowc(c);
       if(w!=WEOF && w>=256)
 	 return 1;
    }
