@@ -161,7 +161,7 @@ const ActionNameRec ActionNameTable[]=
    {EDITOR_OPTIONS,"editor-options"},
    {TERMINAL_OPTIONS,"terminal-options"},
    {FORMAT_OPTIONS,"format-options"},
-   {APPEARENCE_OPTIONS,"appearence-options"},
+   {APPEARANCE_OPTIONS,"appearance-options"},
    {SAVE_OPTIONS,"save-options"},
    {SAVE_OPTIONS_LOCAL,"save-options-local"},
 
@@ -868,7 +868,8 @@ int   GetNextAction()
 	    if(kt==KeyTree)
 	       return MOUSE_ACTION;
 	    MEVENT mev;
-	    while(getmouse(&mev)==OK)
+	    int limit=100; // workaround for ncurses bug
+	    while(getmouse(&mev)==OK && limit-->0)
 	       ;  // flush mouse event queue
 	    continue;
 	 }
