@@ -143,7 +143,7 @@ enum  Action
    EDITOR_OPTIONS,
    TERMINAL_OPTIONS,
    FORMAT_OPTIONS,
-   APPEARENCE_OPTIONS,
+   APPEARANCE_OPTIONS,
    PROGRAM_OPTIONS,
    UNDO_OPTIONS,
    COLOR_TUNING,
