@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: options.cc,v 1.39 2009/05/22 06:21:06 lav Exp $ */
+/* $Id: options.cc,v 1.41 2009/12/12 16:58:14 lav Exp $ */
 
 #include <config.h>
 #include <ctype.h>
@@ -1143,7 +1143,7 @@ void  FormatOptions(void)
 }
 void  AppearOpt(void)
 {
-   Dialogue(AppearOptTbl,26,11," Appearence Options ",NULL,NULL,TOEatKey,TOHandleBut);
+   Dialogue(AppearOptTbl,26,11," Appearance Options ",NULL,NULL,TOEatKey,TOHandleBut);
 }
 void  ProgOpt(void)
 {
@@ -1245,7 +1245,7 @@ int ColorHandleBut(const char *button,int index)
                 FindColor(new_bw_pal,color_no));
       return -1;
    }
-   char *l=strchr(button,'&');
+   const char *l=strchr(button,'&');
    if(!l)
       return -1;
    char res=toupper(l[1]);
