@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: textpoin.cc,v 1.18 2006/06/20 12:03:03 lav Exp $ */
+/* $Id: textpoin.cc,v 1.19 2008/09/02 05:01:15 lav Exp $ */
 
 #include <config.h>
 #include <limits.h>
@@ -393,3 +393,16 @@ TextPoint TextPoint::ForcedLineCol(num l,num c)
    stdcol=old_stdcol;
    return res;
 }
+
+num TextPoint::Line()
+{
+   if(flags&LINEUNDEFINED)
+      FindLineCol();
+   return(line);
+}
+num TextPoint::Col()
+{
+   if(flags&(COLUNDEFINED|LINEUNDEFINED))
+      FindLineCol();
+   return(col);
+}
