@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: textpoin.h,v 1.8 2006/04/19 10:04:52 lav Exp $ */
+/* $Id: textpoin.h,v 1.9 2008/09/02 05:01:48 lav Exp $ */
 
 #ifndef TEXTPOINT_H
 #define TEXTPOINT_H
@@ -52,18 +52,9 @@ public:
    {
       return(offset);
    }
-   num   Line()
-   {
-      if(flags&LINEUNDEFINED)
-         FindLineCol();
-      return(line);
-   }
-   num   Col()
-   {
-      if(flags&(COLUNDEFINED|LINEUNDEFINED))
-         FindLineCol();
-      return(col);
-   }
+   num   Line();
+   num   Col();
+
    num	 LineSimple()
    {
       if(flags&LINEUNDEFINED)
