@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: user.cc,v 1.55 2006/11/29 07:10:25 lav Exp $ */
+/* $Id: user.cc,v 1.56 2008/10/24 13:37:41 lav Exp $ */
 
 #include <config.h>
 #include <ctype.h>
@@ -37,6 +37,7 @@
 #include "about.h"
 #include "bm.h"
 #include "undo.h"
+#include "highli.h"
 
 void  UserDeleteToEol()
 {
@@ -1044,7 +1045,7 @@ void  UserInfo()
    struct passwd  *pw;
    struct group   *gr;
 
-   DisplayWin(InfoWin=CreateWin(MIDDLE,MIDDLE,40,20,DIALOGUE_WIN_ATTR," Info ",0));
+   DisplayWin(InfoWin=CreateWin(MIDDLE,MIDDLE,50,20,DIALOGUE_WIN_ATTR," Info ",0));
 
    pw=getpwuid(uid);
    gr=getgrgid(gid);
@@ -1072,6 +1073,11 @@ void  UserInfo()
                                               gr?gr->gr_name:"",(long)gid);
       PutStr(3,cl+=2,s);
 
+      if(syntax_hl::selector) {
+	 PutStr(3,cl+=2,"Syntax selector:");
+	 PutStr(3,++cl,syntax_hl::selector);
+      }
+
       refresh();
    }
    while(WaitForKey(1000)==ERR);
